@@ -1,25 +1,30 @@
 # encoding: utf-8
+"""
+URL conf for django-sphinxdoc.
 
-from django.conf.urls.defaults import *
+"""
+
+from django.conf.urls.defaults import patterns, url
 from django.views.generic import list_detail
 
 from sphinxdoc import models
+from sphinxdoc.views import ProjectSearchView
 
-app_info = {
-    'queryset': models.App.objects.all().order_by('name'),
-    'template_object_name': 'app',
+
+project_info = {
+    'queryset': models.Project.objects.all().order_by('name'),
+    'template_object_name': 'project',
 }
 
-
 urlpatterns = patterns('sphinxdoc.views',
     url(
         r'^$',
         list_detail.object_list,
-        app_info,
+        project_info,
     ),
     url(
         r'^(?P<slug>[\w-]+)/search/$',
-        'search',
+        ProjectSearchView(),
         name='doc-search',
     ),
     url(
@@ -38,11 +43,11 @@ urlpatterns = patterns('sphinxdoc.views',
     url(
         r'^(?P<slug>[\w-]+)/$',
         'documentation',
-        {'url': ''},
+        {'path': ''},
         name='doc-index',
     ),
     url(
-        r'^(?P<slug>[\w-]+)/(?P<url>(([\w-]+)/)+)$',
+        r'^(?P<slug>[\w-]+)/(?P<path>(([\w-]+)/)+)$',
         'documentation',
         name='doc-detail',
     ),
